grenadine.Evaluation package
============================

Module contents
---------------

.. automodule:: grenadine.Evaluation
    :members:
    :undoc-members:
    :show-inheritance:

grenadine.Evaluation.evaluation module
--------------------------------------

.. automodule:: grenadine.Evaluation.evaluation
    :members:
    :undoc-members:
    :show-inheritance:
